==> bobplates_0.12.10.zip: bobplates_0.12.10/prototypes/item/parts.lua <==
data:extend(
{
  {
    type = "item",
    name = "steel-gear-wheel",
    icon = "__bobplates__/graphics/icons/steel-gear-wheel.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gears",
    order = "b[steel-gear-wheel]",
    stack_size = 100
  },

  {
    type = "item",
    name = "steel-bearing-ball",
    icon = "__bobplates__/graphics/icons/steel-bearing-ball.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[ball-bearing-steel]",
    stack_size = 500
  },

  {
    type = "item",
    name = "steel-bearing",
    icon = "__bobplates__/graphics/icons/steel-bearing.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[bearing-steel]",
    stack_size = 100
  },


  {
    type = "item",
    name = "brass-gear-wheel",
    icon = "__bobplates__/graphics/icons/brass-gear-wheel.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gears",
    order = "b[brass-gear-wheel]",
    stack_size = 100
  },


  {
    type = "item",
    name = "titanium-gear-wheel",
    icon = "__bobplates__/graphics/icons/titanium-gear-wheel.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gears",
    order = "b[titanium-gear-wheel]",
    stack_size = 100
  },

  {
    type = "item",
    name = "titanium-bearing-ball",
    icon = "__bobplates__/graphics/icons/titanium-bearing-ball.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[ball-bearing-titanium]",
    stack_size = 500
  },

  {
    type = "item",
    name = "titanium-bearing",
    icon = "__bobplates__/graphics/icons/titanium-bearing.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[bearing-titanium]",
    stack_size = 100
  },


  {
    type = "item",
    name = "tungsten-gear-wheel",
    icon = "__bobplates__/graphics/icons/tungsten-gear-wheel.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gears",
    order = "b[tungsten-gear-wheel]",
    stack_size = 100
  },


  {
    type = "item",
    name = "nitinol-gear-wheel",
    icon = "__bobplates__/graphics/icons/nitinol-gear-wheel.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gears",
    order = "b[nitinol-gear-wheel]",
    stack_size = 100
  },

  {
    type = "item",
    name = "nitinol-bearing-ball",
    icon = "__bobplates__/graphics/icons/nitinol-bearing-ball.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[ball-bearing-nitinol]",
    stack_size = 500
  },

  {
    type = "item",
    name = "nitinol-bearing",
    icon = "__bobplates__/graphics/icons/nitinol-bearing.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[bearing-nitinol]",
    stack_size = 100
  },


  {
    type = "item",
    name = "ceramic-bearing-ball",
    icon = "__bobplates__/graphics/icons/ceramic-bearing-ball.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[ball-bearing-ceramic]",
    stack_size = 500
  },

  {
    type = "item",
    name = "ceramic-bearing",
    icon = "__bobplates__/graphics/icons/ceramic-bearing.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[bearing-ceramic]",
    stack_size = 100
  },


  {
    type = "item",
    name = "lithium-ion-battery",
    icon = "__bobplates__/graphics/icons/lithium-ion-battery.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-intermediates",
    order = "f-c[lithium-ion-battery]",
    stack_size = 200
  },

  {
    type = "item",
    name = "silver-zinc-battery",
    icon = "__bobplates__/graphics/icons/silver-zinc-battery.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-intermediates",
    order = "f-c[silver-zinc-battery]",
    stack_size = 200
  },


  {
    type = "item",
    name = "grinding-wheel",
    icon = "__bobplates__/graphics/icons/grinding-wheel.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-intermediates",
    order = "f-c[grinding-wheel]",
    stack_size = 100
  },

  {
    type = "item",
    name = "polishing-wheel",
    icon = "__bobplates__/graphics/icons/polishing-wheel.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-intermediates",
    order = "f-c[polishing-wheel]",
    stack_size = 100
  },
}
)

==> bobplates_0.16.2.zip: bobplates_0.16.2/prototypes/item/parts.lua <==
data:extend(
{
  {
    type = "item",
    name = "steel-gear-wheel",
    icon = "__bobplates__/graphics/icons/steel-gear-wheel.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gears",
    order = "b[steel-gear-wheel]",
    stack_size = 100
  },

  {
    type = "item",
    name = "steel-bearing-ball",
    icon = "__bobplates__/graphics/icons/steel-bearing-ball.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[ball-bearing-steel]",
    stack_size = 500
  },

  {
    type = "item",
    name = "steel-bearing",
    icon = "__bobplates__/graphics/icons/steel-bearing.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[bearing-steel]",
    stack_size = 100
  },


  {
    type = "item",
    name = "brass-gear-wheel",
    icon = "__bobplates__/graphics/icons/brass-gear-wheel.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gears",
    order = "b[brass-gear-wheel]",
    stack_size = 100
  },


  {
    type = "item",
    name = "cobalt-steel-gear-wheel",
    icon = "__bobplates__/graphics/icons/cobalt-steel-gear-wheel.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gears",
    order = "b[cobalt-steel-gear-wheel]",
    stack_size = 100
  },

  {
    type = "item",
    name = "cobalt-steel-bearing-ball",
    icon = "__bobplates__/graphics/icons/cobalt-steel-bearing-ball.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[ball-bearing-cobalt-steel]",
    stack_size = 500
  },

  {
    type = "item",
    name = "cobalt-steel-bearing",
    icon = "__bobplates__/graphics/icons/cobalt-steel-bearing.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[bearing-cobalt-steel]",
    stack_size = 100
  },


  {
    type = "item",
    name = "titanium-gear-wheel",
    icon = "__bobplates__/graphics/icons/titanium-gear-wheel.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gears",
    order = "b[titanium-gear-wheel]",
    stack_size = 100
  },

  {
    type = "item",
    name = "titanium-bearing-ball",
    icon = "__bobplates__/graphics/icons/titanium-bearing-ball.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[ball-bearing-titanium]",
    stack_size = 500
  },

  {
    type = "item",
    name = "titanium-bearing",
    icon = "__bobplates__/graphics/icons/titanium-bearing.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[bearing-titanium]",
    stack_size = 100
  },


  {
    type = "item",
    name = "tungsten-gear-wheel",
    icon = "__bobplates__/graphics/icons/tungsten-gear-wheel.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gears",
    order = "b[tungsten-gear-wheel]",
    stack_size = 100
  },


  {
    type = "item",
    name = "nitinol-gear-wheel",
    icon = "__bobplates__/graphics/icons/nitinol-gear-wheel.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gears",
    order = "b[nitinol-gear-wheel]",
    stack_size = 100
  },

  {
    type = "item",
    name = "nitinol-bearing-ball",
    icon = "__bobplates__/graphics/icons/nitinol-bearing-ball.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[ball-bearing-nitinol]",
    stack_size = 500
  },

  {
    type = "item",
    name = "nitinol-bearing",
    icon = "__bobplates__/graphics/icons/nitinol-bearing.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[bearing-nitinol]",
    stack_size = 100
  },


  {
    type = "item",
    name = "ceramic-bearing-ball",
    icon = "__bobplates__/graphics/icons/ceramic-bearing-ball.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[ball-bearing-ceramic]",
    stack_size = 500
  },

  {
    type = "item",
    name = "ceramic-bearing",
    icon = "__bobplates__/graphics/icons/ceramic-bearing.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-bearings",
    order = "b[bearing-ceramic]",
    stack_size = 100
  },


  {
    type = "item",
    name = "lithium-ion-battery",
    icon = "__bobplates__/graphics/icons/lithium-ion-battery.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-intermediates",
    order = "f-c[lithium-ion-battery]",
    stack_size = 200
  },

  {
    type = "item",
    name = "silver-zinc-battery",
    icon = "__bobplates__/graphics/icons/silver-zinc-battery.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-intermediates",
    order = "f-c[silver-zinc-battery]",
    stack_size = 200
  },


  {
    type = "item",
    name = "grinding-wheel",
    icon = "__bobplates__/graphics/icons/grinding-wheel.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-intermediates",
    order = "f-c[grinding-wheel]",
    stack_size = 100
  },

  {
    type = "item",
    name = "polishing-wheel",
    icon = "__bobplates__/graphics/icons/polishing-wheel.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-intermediates",
    order = "f-c[polishing-wheel]",
    stack_size = 100
  },
}
)
